#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Tests for ingest_envoy.collectors
"""
from unittest.mock import patch

from ingest_envoy.collectors import ImageCollector, collect_image_metadata, aux_file_to_staging
from ingest_envoy.schema import AbstractTextFile

parameters = {
    "sdmId": "brain_000.58099.67095825232",
    "telescope": "EVLA",
    "workflowName": "std_cms_imaging",
    "workflowRequestId": "12",
    "spl": "uid://evla/execblock/ec082e65-452d-4fec-ad88-f5b4af1f9e36",
    "processingStart": "2021_07_06T21_50_48",
    "destinationDir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmprb1se376",
    "workflowDir": "tmprb1se376",
    "calSpl": "uid://evla/calibration/c78ccfd6-fe4e-43c6-a5c5-70e5bcfde16b",
    "staging_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/staging",
    "storage_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/storage",
}

image_collector = ImageCollector(parameters=parameters)


@patch("builtins.open")
def test_collect_image_metadata(mock_open):
    aux = collect_image_metadata()
    assert mock_open.call_count == 1
    assert isinstance(aux, AbstractTextFile)


def test_aux_file_to_staging():
    with patch("shutil.copy2") as mock_copy2:
        aux_file_to_staging(parameters["staging_area"] + "/" + parameters["workflowDir"])
        assert mock_copy2.call_count == 1


class TestImageCollector:
    @patch("shutil.copy2")
    @patch("subprocess.run")
    def test_collect_image_products(self, mock_run, mock_copy):
        mock_run.return_value.returncode = 0
        image_collector.collect_products()
        assert mock_run.call_count == 1

    def test_create_artifacts_name(self):
        expected_name = "pipeline_artifacts_" + parameters["processingStart"]

        name = image_collector.create_artifacts_name()
        assert name == expected_name
